@@ -3,7 +3,7 @@ from nctoolkit.session import nc_safe, append_safe, remove_safe
 from nctoolkit.temp_file import temp_file
 
 
-def to_latlon(self, lon=None, lat=None, res=None, method="bil"):
+def to_latlon(self, lon=None, lat=None, res=None, method="bil", recycle = False):
     """
     Regrid a dataset to a regular latlon grid
 
@@ -18,9 +18,25 @@ def to_latlon(self, lon=None, lat=None, res=None, method="bil"):
         of the target grid. If 2 element list is given, the first element is the
         longitudinal resolution and the second is the latitudinal resolution.
     method : str
-        remapping method. Defaults to "bil". Bilinear: "bil"; Nearest neighbour: "nn".
+        Remapping method. Defaults to "bil". Methods available are:
+        bilinear - "bil";
+        nearest neighbour - "nn" - "nearest neighbour"
+        bicubic interpolation - "bic"
+        Distance-weighted average - "dis"
+        First order conservative remapping - "con"
+        Second order conservative remapping - "con2"
+        Large area fraction remapping - "laf"
+    recycle : bool
+        Do you want the grid and weights to be available for recycling and use in regrid?
+        Defaults to False
+
     """
 
+    valid_methods = ["bil", "nn", "bic", "dis", "con", "con2", "laf"]
+
+    if method not in valid_methods:
+        raise ValueError(f"{mm} is not a valid method!")
+
     if lon is None:
         raise ValueError("Please supply lon")
     if lat is None:
@@ -100,7 +116,7 @@ def to_latlon(self, lon=None, lat=None, res=None, method="bil"):
     append_safe(grid_file)
 
     # call regrid
-    self.regrid(grid=grid_file, method=method)
+    self.regrid(grid=grid_file, method=method, recycle = recycle)
 
     remove_safe(grid_file)
 
